﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Vintagestory.API.Common;
using Vintagestory.API.Common.Entities;
using Vintagestory.API.MathTools;

namespace locustmod.src
{
    public class Drill : ModSystem
    {

        public override void Start(ICoreAPI api)
        {
            base.Start(api);
            api.RegisterItemClass("drill", typeof(DrillItem));
        }

    }
    public class DrillItem : Item
    {
        public override bool OnBlockBrokenWith(IWorldAccessor world, Entity byEntity, ItemSlot itemslot,
            BlockSelection blockSel, float dropQuantityMultiplier = 1)
        {
            if (base.OnBlockBrokenWith(world, byEntity, itemslot, blockSel, dropQuantityMultiplier))
            {
                if (byEntity is EntityPlayer)
                {
                    var player = world.PlayerByUid((byEntity as EntityPlayer).PlayerUID);
                    switch (blockSel.Face.Axis)
                    {
                        case EnumAxis.X:
                            destroyBlocks(world, blockSel.Position.AddCopy(0, -1, -1),
                                blockSel.Position.AddCopy(0, 1, 1), player, blockSel.Position);
                            break;
                        case EnumAxis.Y:
                            destroyBlocks(world, blockSel.Position.AddCopy(-1, 0, -1),
                                blockSel.Position.AddCopy(1, 0, 1), player, blockSel.Position);
                            break;
                        case EnumAxis.Z:
                            destroyBlocks(world, blockSel.Position.AddCopy(-1, -1, 0),
                                blockSel.Position.AddCopy(1, 1, 0), player, blockSel.Position);
                            break;
                    }
                }

                return true;
            }

            return false;
        }
        //credit to stitch37 for this code
        public void destroyBlocks(IWorldAccessor world, BlockPos min, BlockPos max, IPlayer player, BlockPos centerBlockPos)
        {
            var centerBlock = world.BlockAccessor.GetBlock(centerBlockPos);
            var itemStack = new ItemStack(this);
            Block tempBlock;
            var miningTimeMainBlock = GetMiningSpeed(itemStack, centerBlock, player);
            float miningTime;
            var tempPos = new BlockPos();
            for (int x = min.X; x <= max.X; x++)
            {
                for (int y = min.Y; y <= max.Y; y++)
                {
                    for (int z = min.Z; z <= max.Z; z++)
                    {
                        tempPos.Set(x, y, z);
                        tempBlock = world.BlockAccessor.GetBlock(tempPos);
                        if (player.WorldData.CurrentGameMode == EnumGameMode.Creative)
                            world.BlockAccessor.SetBlock(0, tempPos);
                        else
                        {
                            miningTime = tempBlock.GetMiningSpeed(itemStack, tempBlock, player);
                            if (this.ToolTier >= tempBlock.RequiredMiningTier
                                && miningTimeMainBlock * 1.5f >= miningTime
                                && MiningSpeed.ContainsKey(tempBlock.BlockMaterial))
                            {
                                world.BlockAccessor.BreakBlock(tempPos, player);
                            }

                        }
                    }
                }
            }
        }
    }
}
